@@ -6,6 +6,9 @@ import stat
 from common import unittest2
 import pyuv
 
+# Make stat return integers
+os.stat_float_times(False)
+
 
 BAD_FILE = 'test_file_bad'
 TEST_FILE = 'test_file_1234'
@@ -61,11 +64,18 @@ class FSTestLstat(unittest2.TestCase):
         self.loop = pyuv.Loop.default_loop()
         with open(TEST_FILE, 'w') as f:
             f.write('test')
-        pyuv.fs.symlink(self.loop, TEST_FILE, TEST_LINK, 0)
+        try:
+            pyuv.fs.symlink(self.loop, TEST_FILE, TEST_LINK, 0)
+        except pyuv.error.FSError as e:
+            if e.args[0] == pyuv.errno.UV_EPERM:
+                raise unittest2.SkipTest("Symlinks not permitted")
 
     def tearDown(self):
         os.remove(TEST_FILE)
-        os.remove(TEST_LINK)
+        try:
+            os.remove(TEST_LINK)
+        except OSError:
+            pass
 
     def stat_cb(self, loop, path, stat_result, errorno):
         self.errorno = errorno
@@ -373,11 +383,17 @@ class FSTestSymlink(unittest2.TestCase):
         self.errorno = None
         pyuv.fs.symlink(self.loop, TEST_FILE, TEST_LINK, 0, self.symlink_cb)
         self.loop.run()
+        if self.errorno == pyuv.errno.UV_EPERM:
+            raise unittest2.SkipTest("Symlinks not permitted")
         self.assertEqual(self.errorno, None)
         self.assertTrue(os.stat(TEST_LINK).st_mode & stat.S_IFLNK)
 
     def test_symlink_sync(self):
-        pyuv.fs.symlink(self.loop, TEST_FILE, TEST_LINK, 0)
+        try:
+            pyuv.fs.symlink(self.loop, TEST_FILE, TEST_LINK, 0)
+        except pyuv.error.FSError as e:
+            if e.args[0] == pyuv.errno.UV_EPERM:
+                raise unittest2.SkipTest("Symlinks not permitted")
         self.assertTrue(os.stat(TEST_LINK).st_mode & stat.S_IFLNK)
 
 
@@ -387,11 +403,18 @@ class FSTestReadlink(unittest2.TestCase):
         self.loop = pyuv.Loop.default_loop()
         with open(TEST_FILE, 'w') as f:
             f.write('test')
-        pyuv.fs.symlink(self.loop, TEST_FILE, TEST_LINK, 0)
+        try:
+            pyuv.fs.symlink(self.loop, TEST_FILE, TEST_LINK, 0)
+        except pyuv.error.FSError as e:
+            if e.args[0] == pyuv.errno.UV_EPERM:
+                raise unittest2.SkipTest("Symlinks not permitted")
 
     def tearDown(self):
         os.remove(TEST_FILE)
-        os.remove(TEST_LINK)
+        try:
+            os.remove(TEST_LINK)
+        except OSError:
+            pass
 
     def readlink_cb(self, loop, path, errorno):
         self.errorno = errorno
@@ -567,7 +590,8 @@ class FSTestWrite(unittest2.TestCase):
         self.loop.run()
         self.assertEqual(self.bytes_written, 4)
         self.assertEqual(self.errorno, None)
-        self.assertEqual(open(TEST_FILE, 'r').read(), "TEST")
+        with open(TEST_FILE, 'r') as fobj:
+            self.assertEqual(fobj.read(), "TEST")
 
     def test_write_null(self):
         self.bytes_written = None
@@ -576,13 +600,15 @@ class FSTestWrite(unittest2.TestCase):
         self.loop.run()
         self.assertEqual(self.bytes_written, 5)
         self.assertEqual(self.errorno, None)
-        self.assertEqual(open(TEST_FILE, 'r').read(), "TES\x00T")
+        with open(TEST_FILE, 'r') as fobj:
+            self.assertEqual(fobj.read(), "TES\x00T")
 
     def test_write_sync(self):
         self.bytes_written = pyuv.fs.write(self.loop, self.fd, "TEST", -1)
         pyuv.fs.close(self.loop, self.fd)
         self.assertEqual(self.bytes_written, 4)
-        self.assertEqual(open(TEST_FILE, 'r').read(), "TEST")
+        with open(TEST_FILE, 'r') as fobj:
+            self.assertEqual(fobj.read(), "TEST")
 
 
 class FSTestFsync(unittest2.TestCase):
@@ -607,7 +633,8 @@ class FSTestFsync(unittest2.TestCase):
         pyuv.fs.write(self.loop, self.fd, "TEST", -1, self.write_cb)
         self.loop.run()
         pyuv.fs.close(self.loop, self.fd)
-        self.assertEqual(open(TEST_FILE, 'r').read(), "TEST")
+        with open(TEST_FILE, 'r') as fobj:
+            self.assertEqual(fobj.read(), "TEST")
 
     def test_fsync_sync(self):
         self.fd = pyuv.fs.open(self.loop, TEST_FILE, os.O_RDWR|os.O_CREAT|os.O_TRUNC, stat.S_IREAD|stat.S_IWRITE)
@@ -615,7 +642,8 @@ class FSTestFsync(unittest2.TestCase):
         pyuv.fs.fdatasync(self.loop, self.fd)
         pyuv.fs.fsync(self.loop, self.fd)
         pyuv.fs.close(self.loop, self.fd)
-        self.assertEqual(open(TEST_FILE, 'r').read(), "TEST")
+        with open(TEST_FILE, 'r') as fobj:
+            self.assertEqual(fobj.read(), "TEST")
 
 
 class FSTestFtruncate(unittest2.TestCase):
@@ -638,7 +666,8 @@ class FSTestFtruncate(unittest2.TestCase):
         pyuv.fs.ftruncate(self.loop, self.fd, 4, self.ftruncate_cb)
         self.loop.run()
         self.assertEqual(self.errorno, None)
-        self.assertEqual(open(TEST_FILE, 'r').read(), "test")
+        with open(TEST_FILE, 'r') as fobj:
+            self.assertEqual(fobj.read(), "test")
 
     def test_ftruncate2(self):
         self.errorno = None
@@ -646,13 +675,15 @@ class FSTestFtruncate(unittest2.TestCase):
         pyuv.fs.ftruncate(self.loop, self.fd, 0, self.ftruncate_cb)
         self.loop.run()
         self.assertEqual(self.errorno, None)
-        self.assertEqual(open(TEST_FILE, 'r').read(), "")
+        with open(TEST_FILE, 'r') as fobj:
+            self.assertEqual(fobj.read(), "")
 
     def test_ftruncate_sync(self):
         fd = pyuv.fs.open(self.loop, TEST_FILE, os.O_RDWR, stat.S_IREAD|stat.S_IWRITE)
         pyuv.fs.ftruncate(self.loop, fd, 0)
         pyuv.fs.close(self.loop, fd)
-        self.assertEqual(open(TEST_FILE, 'r').read(), "")
+        with open(TEST_FILE, 'r') as fobj:
+            self.assertEqual(fobj.read(), "")
 
 
 class FSTestReaddir(unittest2.TestCase):
@@ -735,7 +766,9 @@ class FSTestSendfile(unittest2.TestCase):
         pyuv.fs.close(self.loop, fd)
         pyuv.fs.close(self.loop, fd2)
         self.assertEqual(self.errorno, None)
-        self.assertEqual(open(TEST_FILE, 'r').read(), open(TEST_FILE2, 'r').read())
+        with open(TEST_FILE, 'r') as fobj1:
+            with open(TEST_FILE2, 'r') as fobj2:
+                self.assertEqual(fobj1.read(), fobj2.read())
 
     def test_sendfile_sync(self):
         fd = pyuv.fs.open(self.loop, TEST_FILE, os.O_RDWR, stat.S_IREAD|stat.S_IWRITE)
@@ -743,7 +776,9 @@ class FSTestSendfile(unittest2.TestCase):
         self.bytes_written = pyuv.fs.sendfile(self.loop, fd2, fd, 0, 131072)
         pyuv.fs.close(self.loop, fd)
         pyuv.fs.close(self.loop, fd2)
-        self.assertEqual(open(TEST_FILE, 'r').read(), open(TEST_FILE2, 'r').read())
+        with open(TEST_FILE, 'r') as fobj1:
+            with open(TEST_FILE2, 'r') as fobj2:
+                self.assertEqual(fobj1.read(), fobj2.read())
 
 
 class FSTestUtime(unittest2.TestCase):
@@ -830,14 +865,13 @@ class FSEventTestBasic(unittest2.TestCase):
         self.errorno = None
         self.events = None
         self.filename = None
-        fs_event = pyuv.fs.FSEvent(self.loop)
-        fs_event.start(TEST_FILE, self.on_fsevent_cb, 0)
+        fs_event = pyuv.fs.FSEvent(self.loop, TEST_FILE, self.on_fsevent_cb, 0)
         timer = pyuv.Timer(self.loop)
         timer.start(self.timer_cb, 1, 0)
         self.loop.run()
         self.assertEqual(self.errorno, None)
         self.assertTrue(self.filename == None or self.filename == TEST_FILE)
-        self.assertTrue(self.events & pyuv.fs.UV_RENAME)
+        self.assertTrue(self.events in (pyuv.fs.UV_CHANGE, pyuv.fs.UV_RENAME))
 
 
 class FSEventTest(unittest2.TestCase):
@@ -875,8 +909,7 @@ class FSEventTest(unittest2.TestCase):
         self.errorno = None
         self.events = None
         self.filename = None
-        fs_event = pyuv.fs.FSEvent(self.loop)
-        fs_event.start(TEST_DIR, self.on_fsevent_cb, 0)
+        fs_event = pyuv.fs.FSEvent(self.loop, TEST_DIR, self.on_fsevent_cb, 0)
         timer = pyuv.Timer(self.loop)
         timer.start(self.timer_cb2, 1, 0)
         self.loop.run()
@@ -892,8 +925,7 @@ class FSEventTest(unittest2.TestCase):
         self.errorno = None
         self.events = None
         self.filename = None
-        fs_event = pyuv.fs.FSEvent(self.loop)
-        fs_event.start(os.path.join(TEST_DIR, TEST_FILE), self.on_fsevent_cb, 0)
+        fs_event = pyuv.fs.FSEvent(self.loop, os.path.join(TEST_DIR, TEST_FILE), self.on_fsevent_cb, 0)
         timer = pyuv.Timer(self.loop)
         timer.start(self.timer_cb3, 1, 0)
         self.loop.run()
